"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/builtin/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.styles = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/builtin/extends"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/builtin/objectWithoutProperties"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/builtin/defineProperty"));

var _objectSpread3 = _interopRequireDefault(require("@babel/runtime/helpers/builtin/objectSpread"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _withStyles = _interopRequireDefault(require("../styles/withStyles"));

var _ButtonBase = _interopRequireDefault(require("../ButtonBase"));

var _helpers = require("../utils/helpers");

// @inheritedComponent ButtonBase
var colors = ['primary', 'secondary', 'error', 'warning', 'success', 'grey'];

var styles = function styles(theme) {
  return (0, _objectSpread3.default)({
    root: (0, _objectSpread3.default)({}, theme.typography.button, {
      boxSizing: 'border-box',
      minWidth: theme.spacing.unit * 8,
      minHeight: 36,
      padding: "".concat(theme.spacing.unit, "px ").concat(theme.spacing.unit * 2, "px"),
      borderRadius: 2,
      transition: theme.transitions.create(['background-color'], {
        duration: theme.transitions.duration.short
      })
    }),
    flat: {},
    outlined: {
      border: [[1, 'solid', '#fff']],
      padding: [[theme.spacing.xsmall - 1, theme.spacing.small - 1]],
      '& > *': {
        color: 'inherit'
      }
    },
    raised: {},
    inverted: {
      backgroundColor: theme.palette.common.white
    }
  }, colors.reduce(function (classes, color) {
    var _theme$palette$color = theme.palette[color],
        main = _theme$palette$color.main,
        light = _theme$palette$color.light,
        dark = _theme$palette$color.dark,
        contrastText = _theme$palette$color.contrastText;
    return (0, _objectSpread3.default)({}, classes, (0, _defineProperty2.default)({}, color, {
      '&$raised': {
        color: contrastText,
        backgroundColor: main,
        '&:not($disabled)': {
          '&:hover, &:focus': {
            backgroundColor: light
          },
          '&:active': {
            backgroundColor: dark
          }
        },
        // Reset on touch devices, it doesn't add specificity
        '@media (hover: none)': {
          backgroundColor: main
        },
        '&$disabled': {
          backgroundColor: theme.palette.common.light
        }
      },
      '&$outlined': {
        color: main,
        borderColor: main,
        '&:not($disabled)': {
          '&:hover': {
            borderColor: dark,
            color: dark
          },
          '&:active, &:focus': {
            borderColor: light,
            color: light
          }
        },
        '&$disabled': {
          color: theme.palette.common.light,
          borderColor: theme.palette.common.light
        }
      },
      '&$inverted': {
        color: main,
        '&:not($disabled)': {
          '&:hover': {
            color: dark
          },
          '&:active, &:focus': {
            color: light
          }
        },
        '&$disabled': {
          color: theme.palette.common.light
        }
      }
    }));
  }, {}), {
    disabled: {},
    sizeSmall: {
      padding: "".concat(theme.spacing.unit - 1, "px ").concat(theme.spacing.unit, "px"),
      minWidth: theme.spacing.unit * 8,
      minHeight: 32,
      fontSize: theme.typography.pxToRem(13)
    },
    sizeLarge: {
      padding: "".concat(theme.spacing.unit, "px ").concat(theme.spacing.unit * 3, "px"),
      minWidth: theme.spacing.unit * 14,
      minHeight: 40,
      fontSize: theme.typography.pxToRem(15)
    },
    fullWidth: {
      width: '100%'
    }
  });
};

exports.styles = styles;

function Button(props) {
  var _classNames;

  var children = props.children,
      classes = props.classes,
      classNameProp = props.className,
      color = props.color,
      disabled = props.disabled,
      disableFocusRipple = props.disableFocusRipple,
      fullWidth = props.fullWidth,
      size = props.size,
      variant = props.variant,
      other = (0, _objectWithoutProperties2.default)(props, ["children", "classes", "className", "color", "disabled", "disableFocusRipple", "fullWidth", "size", "variant"]);
  var className = (0, _classnames.default)(classes.root, (_classNames = {}, (0, _defineProperty2.default)(_classNames, classes.raised, variant === 'raised'), (0, _defineProperty2.default)(_classNames, classes.flat, variant === 'flat'), (0, _defineProperty2.default)(_classNames, classes.outlined, variant === 'outlined'), (0, _defineProperty2.default)(_classNames, classes.inverted, variant === 'inverted'), (0, _defineProperty2.default)(_classNames, classes["size".concat((0, _helpers.capitalize)(size))], size !== 'medium'), (0, _defineProperty2.default)(_classNames, classes.disabled, disabled), (0, _defineProperty2.default)(_classNames, classes.fullWidth, fullWidth), _classNames), classes[color], classNameProp);
  return _react.default.createElement(_ButtonBase.default, (0, _extends2.default)({
    className: className,
    disabled: disabled,
    focusRipple: !disableFocusRipple
  }, other), children);
}

Button.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * The content of the button.
   */
  children: _propTypes.default.node.isRequired,

  /**
   * Override or extend the styles applied to the component.
   * See [CSS API](#css-api) below for more details.
   */
  classes: _propTypes.default.object.isRequired,

  /**
   * @ignore
   */
  className: _propTypes.default.string,

  /**
   * The color of the component. It supports those theme colors that make sense for this component.
   */
  color: _propTypes.default.oneOf(colors),

  /**
   * The component used for the root node.
   * Either a string to use a DOM element or a component.
   */
  component: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.func]),

  /**
   * If `true`, the button will be disabled.
   */
  disabled: _propTypes.default.bool,

  /**
   * If `true`, the  keyboard focus ripple will be disabled.
   * `disableRipple` must also be true.
   */
  disableFocusRipple: _propTypes.default.bool,

  /**
   * If `true`, the ripple effect will be disabled.
   */
  disableRipple: _propTypes.default.bool,

  /**
   * If `true`, the button will take up the full width of its container.
   */
  fullWidth: _propTypes.default.bool,

  /**
   * The URL to link to when the button is clicked.
   * If defined, an `a` element will be used as the root node.
   */
  href: _propTypes.default.string,

  /**
   * The size of the button.
   * `small` is equivalent to the dense button styling.
   */
  size: _propTypes.default.oneOf(['small', 'medium', 'large']),

  /**
   * @ignore
   */
  type: _propTypes.default.string,

  /**
   * The type of button.
   */
  variant: _propTypes.default.oneOf(['flat', 'outlined', 'raised', 'inverted'])
} : {};
Button.defaultProps = {
  color: 'primary',
  component: 'button',
  disabled: false,
  disableRipple: true,
  disableFocusRipple: true,
  fullWidth: false,
  size: 'medium',
  type: 'button',
  variant: 'raised'
};

var _default = (0, _withStyles.default)(styles, {
  name: 'MuiButton'
})(Button);

exports.default = _default;