"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/builtin/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactMotion = require("react-motion");

var _classnames = _interopRequireDefault(require("classnames"));

var _withStyles = _interopRequireDefault(require("../styles/withStyles"));

var _Typography = _interopRequireDefault(require("../Typography"));

var strokeWidth = 8;

var styles = function styles(theme) {
  return {
    root: {
      position: 'relative',
      width: 144,
      height: 'auto'
    },
    progress: {
      overflow: 'visible',
      width: '100%',
      height: 'auto',
      fill: 'none',
      stroke: 'white',
      strokeWidth: theme.spacing.unit,
      transform: 'rotate(-90deg) translate3d(50%, 50%, 0)'
    },
    progressBackground: {
      opacity: 0.5
    },
    label: {
      lineHeight: 1,
      fontSize: theme.typography.pxToRem(40),
      fontWeight: 700,
      color: 'white',
      position: 'absolute',
      top: '50%',
      left: '50%',
      transform: 'translate(-50%,-50%)'
    }
  };
};

function getDonutPartialPath(min, value, max) {
  var ratio = Math.max(0, Math.min(0.99999, (value - min) / (max - min))); // Polar coordinates to rectangular: http://mathworld.wolfram.com/PolarCoordinates.html

  var radius = 50 - strokeWidth / 2;
  var originX = radius; // cos(0) = 1

  var originY = 0; // sin(0) = 0

  var angle = ratio * 2 * Math.PI;
  var finalX = radius * Math.cos(angle);
  var finalY = radius * Math.sin(angle); // SVG Arcs: https://developer.mozilla.org/en/docs/Web/SVG/Tutorial/Paths#Arcs

  var largeArc = ratio > 0.5 ? 1 : 0;
  return "M".concat(originX, ",").concat(originY, " A").concat(radius, ",").concat(radius, ", 0, ").concat(largeArc, ", 1, ").concat(finalX, ",").concat(finalY);
}

function getPercentageString(min, value, max) {
  var truncated = Math.max(0, Math.min(1, (value - min) / (max - min)));
  return "".concat(Math.round(100 * truncated), "%");
}

function CircularProgressNumber(_ref) {
  var className = _ref.className,
      style = _ref.style,
      classes = _ref.classes,
      max = _ref.max,
      min = _ref.min,
      value = _ref.value;
  var fullPath = getDonutPartialPath(min, max, max);

  var _ref2 = _react.default.createElement("path", {
    d: fullPath,
    opacity: 0.33
  });

  return _react.default.createElement(_reactMotion.Motion, {
    defaultStyle: {
      progress: 0
    },
    style: {
      progress: (0, _reactMotion.spring)(value - min)
    }
  }, function (current) {
    return _react.default.createElement("div", {
      className: (0, _classnames.default)(classes.root, className),
      style: style
    }, _react.default.createElement("svg", {
      width: "100",
      height: "100",
      viewBox: "0 0 100 100",
      className: classes.progress
    }, _ref2, _react.default.createElement("path", {
      d: getDonutPartialPath(min, current.progress + min, max)
    })), _react.default.createElement(_Typography.default, {
      className: classes.label,
      variant: "display2"
    }, getPercentageString(min, current.progress + min, max)));
  });
}

CircularProgressNumber.propTypes = process.env.NODE_ENV !== "production" ? {
  classes: _propTypes.default.object.isRequired,
  className: _propTypes.default.string,
  max: _propTypes.default.number,
  min: _propTypes.default.number,
  style: _propTypes.default.object,
  value: _propTypes.default.number.isRequired
} : {};
CircularProgressNumber.defaultProps = {
  max: 100,
  min: 0
};

var _default = (0, _withStyles.default)(styles)(CircularProgressNumber);

exports.default = _default;